@@ -1509,6 +1509,12 @@ char *_dom_get_valid_file_path(char *source, char *resolved_path, int resolved_p
 
 	if (uri->scheme != NULL) {
 		/* absolute file uris - libxml only supports localhost or empty host */
+#ifdef PHP_WIN32
+		if (strncasecmp(source, "file://",7) == 0 && ':' == source[8]) {
+			isFileUri = 1;
+			source += 7;
+		} else
+#endif
 		if (strncasecmp(source, "file:///",8) == 0) {
 			isFileUri = 1;
 #ifdef PHP_WIN32
